'use strict';

var index = require('./dep-ba00609f.js');
var fs = require('fs');
var sysPath = require('path');
var vite = require('vite');
var _merge = require('lodash.merge');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var fs__default = /*#__PURE__*/_interopDefaultLegacy(fs);
var sysPath__default = /*#__PURE__*/_interopDefaultLegacy(sysPath);
var _merge__default = /*#__PURE__*/_interopDefaultLegacy(_merge);

// default value
var defaultOptions = {
  preloadBaseMarker: 'window.__publicPath__'
};
function usePreloadRuntimePublicPath() {
  var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultOptions;
  var _options$preloadBaseM = options.preloadBaseMarker,
      preloadBaseMarker = _options$preloadBaseM === void 0 ? defaultOptions.preloadBaseMarker : _options$preloadBaseM;
  var config;
  return {
    name: 'vite-plugin-dynamic-base',
    enforce: 'pre',
    apply: 'build',
    configResolved: function configResolved(resolvedConfig) {
      config = resolvedConfig;
    },
    renderChunk: function renderChunk(code) {
      code = code.replace("const base = '".concat(config.base, "';const __vitePreload"), "const base = ".concat(preloadBaseMarker, ";const __vitePreload"));
      return code;
    }
  };
}

var mountingCorePlugins = function mountingCorePlugins(config) {
  var _config$build, _config$build2;

  return [// 开启runtimePublicPath插件
  config !== null && config !== void 0 && (_config$build = config.build) !== null && _config$build !== void 0 && _config$build.runtimePublicPath ? usePreloadRuntimePublicPath(config === null || config === void 0 ? void 0 : (_config$build2 = config.build) === null || _config$build2 === void 0 ? void 0 : _config$build2.runtimePublicPath) : null // 代码tree-shaking
  ];
};

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { index._defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
var PRE_CONFIG = {
  single: {
    cssCodeSplit: false,
    rollupOptions: {
      output: {
        assetFileNames: 'index[extname]',
        entryFileNames: 'index.esm.js',
        manualChunks: {}
      }
    }
  },
  split: {
    cssCodeSplit: true,
    rollupOptions: {
      output: {
        assetFileNames: 'index.[hash][extname]',
        entryFileNames: 'index.esm.js'
      }
    }
  },
  'split-js': {
    cssCodeSplit: false,
    rollupOptions: {
      output: {
        assetFileNames: 'index[extname]',
        entryFileNames: 'index.esm.js'
      }
    }
  }
};
function defineConfig(config) {
  return config;
}
function lookupConfigFile() {
  var configRoot = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : process.cwd();
  var configFile = arguments.length > 1 ? arguments[1] : undefined;
  var resolvedPath;

  if (configFile) {
    resolvedPath = sysPath__default["default"].resolve(configFile);
  } else {
    var jsconfigFile = sysPath__default["default"].resolve(configRoot, 'viter.config.js');

    if (fs__default["default"].existsSync(jsconfigFile)) {
      resolvedPath = jsconfigFile;
    }

    if (!resolvedPath) {
      var mjsconfigFile = sysPath__default["default"].resolve(configRoot, 'viter.config.mjs');

      if (fs__default["default"].existsSync(mjsconfigFile)) {
        resolvedPath = mjsconfigFile;
      }
    }

    if (!resolvedPath) {
      var tsconfigFile = sysPath__default["default"].resolve(configRoot, 'viter.config.ts');

      if (fs__default["default"].existsSync(tsconfigFile)) {
        resolvedPath = tsconfigFile;
      }
    }
  }

  return resolvedPath;
}
function resolveConfig(_x, _x2) {
  return _resolveConfig.apply(this, arguments);
}

function _resolveConfig() {
  _resolveConfig = index._asyncToGenerator( /*#__PURE__*/index.regenerator.mark(function _callee(inlineConfig, command) {
    var defaultMode,
        config,
        mode,
        configFile,
        configEnv,
        loadResult,
        resolved,
        _args = arguments;
    return index.regenerator.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            defaultMode = _args.length > 2 && _args[2] !== undefined ? _args[2] : 'development';
            config = inlineConfig;
            mode = config.mode || defaultMode;
            configFile = lookupConfigFile(config.root, config.configFile);
            configEnv = {
              mode: mode,
              command: command
            };
            _context.next = 7;
            return vite.loadConfigFromFile(configEnv, configFile, config.root);

          case 7:
            loadResult = _context.sent;

            if (loadResult) {
              config = vite.mergeConfig(loadResult.config, config);
            }

            resolved = _objectSpread(_objectSpread({}, config), {}, {
              configFile: configFile,
              inlineConfig: inlineConfig
            });
            return _context.abrupt("return", resolved);

          case 11:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));
  return _resolveConfig.apply(this, arguments);
}

function convertConfig(config) {
  var _config$build;

  var configFile = config.configFile;
  var innerConfig = {
    configFile: false,
    server: {
      watch: {
        ignored: [configFile]
      }
    },
    resolve: {
      alias: {
        '@': sysPath__default["default"].resolve(process.cwd(), 'src'),
        '@viter-entry': sysPath__default["default"].resolve(process.cwd(), '.viter')
      }
    }
  }; // 加载预置打包配置

  if (config !== null && config !== void 0 && (_config$build = config.build) !== null && _config$build !== void 0 && _config$build.buildMode) {
    var buildConfig = PRE_CONFIG[config.build.buildMode];
    config.build = _merge__default["default"](config.build, buildConfig);
  }

  var viteConfig = vite.mergeConfig(config, innerConfig);
  delete viteConfig.routes;
  delete viteConfig.dynamicImport;

  if (viteConfig.build && viteConfig.build.manifest) {
    viteConfig.build.manifest = true;
  } // 加载内置插件


  if (Array.isArray(viteConfig.plugins)) {
    var _viteConfig$plugins;

    viteConfig.plugins = (_viteConfig$plugins = viteConfig.plugins) === null || _viteConfig$plugins === void 0 ? void 0 : _viteConfig$plugins.concat(mountingCorePlugins(config));
  } else {
    viteConfig.plugins = mountingCorePlugins(config);
  }

  return viteConfig;
}

exports.convertConfig = convertConfig;
exports.defineConfig = defineConfig;
exports.lookupConfigFile = lookupConfigFile;
exports.resolveConfig = resolveConfig;
//# sourceMappingURL=dep-7c9e8d89.js.map
